]> sigrok.org Git - libsigrok.git/blobdiff - std.c
Create & use new sr_usbtmc_dev_inst for Rigol DS driver.
[libsigrok.git] / std.c
diff --git a/std.c b/std.c
index 059bf759013ef5274af32aa6c797a913c55b3da5..d1ff84e037c29cdb70044ac68d36c33be1ee7328 100644 (file)
--- a/std.c
+++ b/std.c
@@ -37,8 +37,8 @@
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
  *         SR_ERR_MALLOC upon memory allocation errors.
  */
-SR_PRIV int std_hw_init(struct sr_context *sr_ctx, struct sr_dev_driver *di,
-                       const char *prefix)
+SR_PRIV int std_init(struct sr_context *sr_ctx, struct sr_dev_driver *di,
+                    const char *prefix)
 {
        struct drv_context *drvc;
 
@@ -101,6 +101,8 @@ SR_PRIV int std_session_send_df_header(const struct sr_dev_inst *sdi,
        return SR_OK;
 }
 
+#ifdef HAVE_LIBSERIALPORT
+
 /*
  * Standard sr_session_stop() API helper.
  *
@@ -117,10 +119,12 @@ SR_PRIV int std_session_send_df_header(const struct sr_dev_inst *sdi,
  * @param prefix A driver-specific prefix string used for log messages.
  *               Must not be NULL. An empty string is allowed.
  *
* @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
*         SR_ERR upon other errors.
  */
-SR_PRIV int std_hw_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
+SR_PRIV int std_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
                        void *cb_data, dev_close_t dev_close_fn,
                        struct sr_serial_dev_inst *serial, const char *prefix)
 {
@@ -134,7 +138,7 @@ SR_PRIV int std_hw_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
 
        if (sdi->status != SR_ST_ACTIVE) {
                sr_err("%sDevice inactive, can't stop acquisition.", prefix);
-               return SR_ERR;
+               return SR_ERR_DEV_CLOSED;
        }
 
        sr_dbg("%sStopping acquisition.", prefix);
@@ -161,6 +165,8 @@ SR_PRIV int std_hw_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
        return SR_OK;
 }
 
+#endif
+
 /*
  * Standard driver dev_clear() helper.
  *
@@ -201,12 +207,16 @@ SR_PRIV int std_dev_clear(const struct sr_dev_driver *driver,
                        driver->dev_close(sdi);
 
                if (sdi->conn) {
-                        if (sdi->inst_type == SR_INST_SERIAL)
+#if HAVE_LIBSERIALPORT
+                       if (sdi->inst_type == SR_INST_SERIAL)
                                sr_serial_dev_inst_free(sdi->conn);
+#endif
 #if HAVE_LIBUSB_1_0
-                       else if (sdi->inst_type == SR_INST_USB)
+                       if (sdi->inst_type == SR_INST_USB)
                                sr_usb_dev_inst_free(sdi->conn);
 #endif
+                       if (sdi->inst_type == SR_INST_USBTMC)
+                               sr_usbtmc_dev_inst_free(sdi->conn);
                }
                if (clear_private)
                        clear_private(sdi->priv);
@@ -117,10 +119,12 @@ SR_PRIV int std_session_send_df_header(const struct sr_dev_inst *sdi,
  *               Must not be NULL. An empty string is allowed.
  *
- * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
- *         SR_ERR upon other errors.
+ * @retval SR_OK Success.
+ * @retval SR_ERR_ARG Invalid arguments.
+ * @retval SR_ERR_DEV_CLOSED Device is closed.
+ * @retval SR_ERR Other errors.
  */